<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="190"/>
      <source>Convert to points...</source>
      <translation>Pretvori v točke …</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="191"/>
      <location filename="../../Command.cpp" line="193"/>
      <source>Convert to points</source>
      <translation>Pretvori v točke</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="112"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="113"/>
      <source>Export points...</source>
      <translation>Izvozi točke …</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="114"/>
      <location filename="../../Command.cpp" line="116"/>
      <source>Exports a point cloud</source>
      <translation>Izvozi točkovni oblak</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Import points...</source>
      <translation>Uvozi točke …</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <location filename="../../Command.cpp" line="71"/>
      <source>Imports a point cloud</source>
      <translation>Uvozi točkovni oblak</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="320"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <source>Merge point clouds</source>
      <translation>Združi oblake točk</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <location filename="../../Command.cpp" line="324"/>
      <source>Merge several point clouds into one</source>
      <translation>Združi več oblakov točk v enega</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="275"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="276"/>
      <source>Cut point cloud</source>
      <translation>Izreži točkovni oblak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="277"/>
      <location filename="../../Command.cpp" line="279"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Izreži točkovni oblak z izbranim mnogokotnikom</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsStructure</name>
    <message>
      <location filename="../../Command.cpp" line="363"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="364"/>
      <source>Structured point cloud</source>
      <translation>Urejen oblak točk</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="365"/>
      <location filename="../../Command.cpp" line="367"/>
      <source>Convert points to structured point cloud</source>
      <translation>Spremeni točke v urejen oblak točk</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="152"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="153"/>
      <source>Transform Points</source>
      <translation>Preoblikuj točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <location filename="../../Command.cpp" line="156"/>
      <source>Test to transform a point cloud</source>
      <translation>Preizkusite za preoblikovanje točkovnega oblaka</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="88"/>
      <source>Import points</source>
      <translation>Uvozi točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="168"/>
      <source>Transform points</source>
      <translation>Preoblikuj točke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Convert to points</source>
      <translation>Pretvori v točke</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="468"/>
      <location filename="../../ViewProvider.cpp" line="627"/>
      <source>Cut points</source>
      <translation>Izreži točke</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>Uvoz točk ASCII</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Predloga:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Posebne črte</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="72"/>
      <source>Ignore lines starting with:</source>
      <translation>Prezri črte, ki se začnejo s/z:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="79"/>
      <source>Cluster by lines starting with:</source>
      <translation>Združi glede na črte, ki se začnejo s/z:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="88"/>
      <source>First line:</source>
      <translation>Prva črta:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="100"/>
      <source>Ignore</source>
      <translation>Prezri</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="110"/>
      <source>Number of points</source>
      <translation>Število točk</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Oblika točke</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="147"/>
      <location filename="../../DlgPointsRead.ui" line="176"/>
      <location filename="../../DlgPointsRead.ui" line="233"/>
      <source>none</source>
      <translation>brez</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="152"/>
      <location filename="../../DlgPointsRead.ui" line="181"/>
      <location filename="../../DlgPointsRead.ui" line="238"/>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (normalni vektor)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="157"/>
      <location filename="../../DlgPointsRead.ui" line="186"/>
      <location filename="../../DlgPointsRead.ui" line="243"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (normalni vektor 2D)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="162"/>
      <location filename="../../DlgPointsRead.ui" line="191"/>
      <location filename="../../DlgPointsRead.ui" line="248"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (barva)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <location filename="../../DlgPointsRead.ui" line="196"/>
      <location filename="../../DlgPointsRead.ui" line="253"/>
      <source>I (Gray value)</source>
      <translation>I (sivinska vrednost)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="204"/>
      <source>Number separator:</source>
      <translation>Številčno ločilo:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="211"/>
      <location filename="../../DlgPointsRead.ui" line="218"/>
      <location filename="../../DlgPointsRead.ui" line="225"/>
      <source>Next block:</source>
      <translation>Naslednji blok:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="270"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="275"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="280"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="289"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="294"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="302"/>
      <source>Points format:</source>
      <translation>Oblika točk:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Predogled</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Število vrstic v predogledu:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="348"/>
      <source>100</source>
      <translation>100</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>Point formats</source>
      <translation>Formati točk</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>All Files</source>
      <translation>Vse datoteke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="202"/>
      <source>Distance</source>
      <translation type="unfinished">Distance</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="203"/>
      <source>Enter maximum distance:</source>
      <translation>Vnesite največjo razdaljo:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Points tools</source>
      <translation>Orodja za točke</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="38"/>
      <source>&amp;Points</source>
      <translation>&amp;Točke</translation>
    </message>
  </context>
</TS>
